@@ -3,15 +3,16 @@ from django.contrib import admin
 from django.utils.translation import get_language
 from django.utils.translation import ugettext_lazy as _
 
+from django_libs.admin import MultilingualPublishMixin
 from simple_translation.admin import TranslationAdmin
 from simple_translation.utils import get_preferred_translation_from_lang
 
 from .models import Organization
 
 
-class OrganizationAdmin(TranslationAdmin):
+class OrganizationAdmin(MultilingualPublishMixin, TranslationAdmin):
     """Admin for the ``Organization`` model."""
-    list_display = ['title', 'phone', 'website']
+    list_display = ['title', 'phone', 'website', 'is_published']
 
     def title(self, obj):
         lang = get_language()
